# pydicomutils

Python repository building upon pydicom to create a utility package intended to be used when creating DICOM objects.

## Installation
```bash
pip install pydicomutils
```

## Usage
In the folder `examples`, a number of example scripts are available, showcasing how the package can be used to create various DICOM objects.
```bash
# Assuming pydicomutils to alread be installed
git clone https://github.com/sectra-medical/pydicomutils.git
cd pydicomutils
pip install examples/requirements.txt
python examples/run_all_examples.py
```